Struct WpCommitTimingManagerV1
pub struct WpCommitTimingManagerV1 { /* private fields */ }wayland and Linux only.Expand description
commit timing
When a compositor latches on to new content updates it will check for any number of requirements of the available content updates (such as fences of all buffers being signalled) to consider the update ready.
This protocol provides a method for adding a time constraint to surface content. This constraint indicates to the compositor that a content update should be presented as closely as possible to, but not before, a specified time.
This protocol does not change the Wayland property that content updates are applied in the order they are received, even when some content updates contain timestamps and others do not.
To provide timestamps, this global factory interface must be used to acquire a wp_commit_timing_v1 object for a surface, which may then be used to provide timestamp information for commits.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Request enum for this interface.